==> primeng-8.1.4.tgz: package/LICENSE.md <==
### PRIMENG COMMERCIAL LICENSE AGREEMENT

THIS COMMERCIAL LICENSE AGREEMENT (THIS “CLA”) CONTAINS THE TERMS AND CONDITIONS FOR YOUR USE OF “PRIMENG”, A SUITE OF Angular Components (THE “Software”). THIS CLA IS A BINDING AGREEMENT BETWEEN YOU (“Licensee”) AND PrimeTek Bilişim. (“Licensor“); HOWEVER, IF YOU ARE ACTING AS AN AGENT FOR ANOTHER, SUCH AS ON BEHALF OF YOUR EMPLOYER, THEN “YOU” MEANS THE OTHER PERSON. BY INSTALLING, COPYING, USING OR OTHERWISE ACCESSING THE SOFTWARE, YOU AGREE TO BE BOUND BY THESE TERMS AND CONDITIONS.

The term “Software” includes all source and object code, in whole and/or part; all printed materials; “online” or electronic documentation; data, data engines, images; updates and upgrades; and anything provided for use with or in conjunction with the Software.

### Summary

*   Can be used on unlimited sites and servers
*   Source-code cannot be resold or distributed
*   Commercial use allowed
*   Can modify source-code but cannot distribute modifications (derivative works)

### Terms and Conditions

1.  **License Grant:** Licensor hereby grants Licensee a Personal, Non-assignable and non-transferable, Commercial, Royalty free, Including the rights to create but not distribute derivative works, Non-exclusive license identified with a unique key stated in section 3, all with accordance with the terms set forth and other legal restrictions set forth in 3rd party software used while running Software.
    
    1.  **Limited:** Licensee may use Software for the purpose of:
        
        1.  Running Software on Licensee’s Website\[s\] and Server\[s\];
        2.  Allowing 3rd Parties to run Software on Licensee’s Website\[s\] and Server\[s\];
        3.  Publishing Software’s output to Licensee and 3rd Parties;
        4.  Distribute verbatim copies of Software’s output (including compiled binaries);
        5.  Modify Software to suit Licensee’s needs and specifications.
    2.  **Non Assignable and Non-Transferable:** Licensee may not assign or transfer his rights and duties under this license.
        
    3.  **Commercial, Royalty Free:** Licensee may use Software for any purpose, including paid-services, without any royalties
        
    4.  **Including the Right to Create Derivative Works:** Licensee may create derivative works based on Software, including amending Software’s source code, modifying it, integrating it into a larger work or removing portions of Software, as long as no distribution of the derivative works is made
        
2.  **Term & Termination:** The Term of this license shall be until terminated. Licensor may terminate this Agreement, including Licensee’s license in the case where Licensee :
    1.  became insolvent or otherwise entered into any liquidation process; or
        
    2.  exported The Software to any jurisdiction where licensor may not enforce his rights under this agreements in; or
        
    3.  Licensee was in breach of any of this license's terms and conditions and such breach was not cured, immediately upon notification; or
        
    4.  Licensee in breach of any of the terms of clause 2 to this license; or
        
    5.  Licensee otherwise entered into any arrangement which caused Licensor to be unable to enforce his rights under this License.
        
3.  **Payment:** In consideration of the License granted under clause 2, Licensee shall pay Licensor a fee, via credit card or any other mean which Licensor may deem adequate. Failure to perform payment shall construe as material breach of this Agreement. Transaction id of the payment is the unique license key granted to Licensee.
4.  **Upgrades, Updates and Fixes:** .
    
    1.  **Fix:** for the purpose of this license, a fix shall be a minor amendment in The Software, intended to remove bugs or alter minor features which impair the The Software's functionality. A fix shall be marked as a new sub-sub-version number. For example, should Licensee purchase Software under version 1.1.1, an upgrade shall commence under number 1.1.2.
        
5.  **Support:** Software is provided under an AS-IS basis and without any support, updates or maintenance. Nothing in this Agreement shall require Licensor to provide Licensee with support or fixes to any bug, failure, mis-performance or other defect in The Software.
    
6.  **Liability:** To the extent permitted under Law, The Software is provided under an AS-IS basis. Licensor shall never, and without any limit, be liable for any damage, cost, expense or any other payment incurred by Licesee as a result of Software’s actions, failure, bugs and/or any other interaction between The Software and Licesee’s end-equipment, computers, other software or any 3rd party, end-equipment, computer or services. Moreover, Licensor shall never be liable for any defect in source code written by Licensee when relying on The Software or using The Software’s source code.
    
7.  **Warranty:**
    
    1.  **Intellectual Property:** Licensor hereby warrants that The Software does not violate or infringe any 3rd party claims in regards to intellectual property, patents and/or trademarks and that to the best of its knowledge no legal action has been taken against it for any infringement or violation of any 3rd party intellectual property rights.
        
    2.  **No-Warranty:** The Software is provided without any warranty; Licensor hereby disclaims any warranty that The Software shall be error free, without defects or code which may cause damage to Licensee’s computers or to Licensee, and that Software shall be functional. Licensee shall be solely liable to any damage, defect or loss incurred as a result of operating software and undertake the risks contained in running The Software on License’s Server\[s\] and Website\[s\].
        
    3.  **Prior Inspection:** Licensee hereby states that he inspected The Software thoroughly and found it satisfactory and adequate to his needs, that it does not interfere with his regular operation and that it does meet the standards and scope of his computer systems and architecture. Licensee found that The Software interacts with his development, website and server environment and that it does not infringe any of End User License Agreement of any software Licensee may use in performing his services. Licensee hereby waives any claims regarding The Software's incompatibility, performance, results and features, and warrants that he inspected the The Software.
        
8.  **No Refunds:** Licensee warrants that he inspected The Software according to clause 7(c) and that it is adequate to his needs. Accordingly, as The Software is intangible goods, Licensee shall not be, ever, entitled to any refund, rebate, compensation or restitution for any reason whatsoever, even if The Software contains material flaws.
    
9.  **Indemnification:** Licensee hereby warrants to hold Licensor harmless and indemnify Licensor for any lawsuit brought against it in regards to Licensee’s use of The Software in means that violate, breach or otherwise circumvent this license, Licensor's intellectual property rights or Licensor's title in The Software. Licensor shall promptly notify Licensee in case of such legal action and request Licensee’s consent prior to any settlement in relation to such lawsuit or claim.
    
10.  **Governing Law, Jurisdiction:** Licensee hereby agrees not to initiate class-action lawsuits against Licensor in relation to this license and to compensate Licensor for any legal fees, cost or attorney fees should any claim brought by Licensee against Licensor be denied, in part or in full.

==> primeng-17.18.14.tgz: package/LICENSE.md <==
# PRIMENG COMMUNITY VERSIONS LICENSE

The MIT License (MIT)

Copyright (c) 2016-2024 PrimeTek

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.

# PRIMENG LTS VERSIONS LICENSE (Versions with -lts suffix)

THIS LICENSE AGREEMENT (THIS “CLA”) CONTAINS THE TERMS AND CONDITIONS FOR YOUR USE OF “PRIMENG LONG TERM SUPPORT”, A SUITE OF Angular Components (THE “Software”). THIS CLA IS A BINDING AGREEMENT BETWEEN YOU (“Licensee”) AND PrimeTek Bilişim. (“Licensor“); HOWEVER, IF YOU ARE ACTING AS AN AGENT FOR ANOTHER, SUCH AS ON BEHALF OF YOUR EMPLOYER, THEN “YOU” MEANS THE OTHER PERSON. BY INSTALLING, COPYING, USING OR OTHERWISE ACCESSING THE SOFTWARE, YOU AGREE TO BE BOUND BY THESE TERMS AND CONDITIONS.

The term “Software” includes all source and object code, in whole and/or part; all printed materials; “online” or electronic documentation; data, data engines, images; updates and upgrades; and anything provided for use with or in conjunction with the Software.

## Summary

-   Can be used on unlimited sites and servers
-   Source-code cannot be resold or distributed
-   Commercial use allowed
-   Can modify source-code but cannot distribute modifications (derivative works)

## Terms and Conditions

1.  **License Grant:** Licensor hereby grants Licensee a Personal, Non-assignable and non-transferable, Commercial, Royalty free, Including the rights to create but not distribute derivative works, Non-exclusive license identified with a unique key stated in section 3, all with accordance with the terms set forth and other legal restrictions set forth in 3rd party software used while running Software.

    1.  **Limited:** Licensee may use Software for the purpose of:

        1.  Running Software on Licensee’s Website\[s\] and Server\[s\];
        2.  Allowing 3rd Parties to run Software on Licensee’s Website\[s\] and Server\[s\];
        3.  Publishing Software’s output to Licensee and 3rd Parties;
        4.  Distribute verbatim copies of Software’s output (including compiled binaries);
        5.  Modify Software to suit Licensee’s needs and specifications.

    2.  **Non Assignable and Non-Transferable:** Licensee may not assign or transfer his rights and duties under this license.
    3.  **Commercial, Royalty Free:** Licensee may use Software for any purpose, including paid-services, without any royalties
    4.  **Including the Right to Create Derivative Works:** Licensee may create derivative works based on Software, including amending Software’s source code, modifying it, integrating it into a larger work or removing portions of Software, as long as no distribution of the derivative works is made

2.  **Term & Termination:** The Term of this license shall be until terminated. Licensor may terminate this Agreement, including Licensee’s license in the case where Licensee :
    1.  became insolvent or otherwise entered into any liquidation process; or
    2.  exported The Software to any jurisdiction where licensor may not enforce his rights under this agreements in; or
    3.  Licensee was in breach of any of this license's terms and conditions and such breach was not cured, immediately upon notification; or
    4.  Licensee in breach of any of the terms of clause 2 to this license; or
    5.  Licensee otherwise entered into any arrangement which caused Licensor to be unable to enforce his rights under this License.
3.  **Payment:** In consideration of the License granted under clause 2, Licensee shall pay Licensor a fee, via credit card or any other mean which Licensor may deem adequate. Failure to perform payment shall construe as material breach of this Agreement. Transaction id of the payment is the unique license key granted to Licensee.
4.  **Upgrades, Updates and Fixes:** .

    1.  **Fix:** for the purpose of this license, a fix shall be a minor amendment in The Software, intended to remove bugs or alter minor features which impair the The Software's functionality. A fix shall be marked as a new sub-sub-version number. For example, should Licensee purchase Software under version 1.1.1, an upgrade shall commence under number 1.1.2.

5.  **Support:** Software is provided under an AS-IS basis and without any support, updates or maintenance. Nothing in this Agreement shall require Licensor to provide Licensee with support or fixes to any bug, failure, mis-performance or other defect in The Software.
6.  **Liability:** To the extent permitted under Law, The Software is provided under an AS-IS basis. Licensor shall never, and without any limit, be liable for any damage, cost, expense or any other payment incurred by Licesee as a result of Software’s actions, failure, bugs and/or any other interaction between The Software and Licesee’s end-equipment, computers, other software or any 3rd party, end-equipment, computer or services. Moreover, Licensor shall never be liable for any defect in source code written by Licensee when relying on The Software or using The Software’s source code.
7.  **Warranty:**

    1.  **Intellectual Property:** Licensor hereby warrants that The Software does not violate or infringe any 3rd party claims in regards to intellectual property, patents and/or trademarks and that to the best of its knowledge no legal action has been taken against it for any infringement or violation of any 3rd party intellectual property rights.
    2.  **No-Warranty:** The Software is provided without any warranty; Licensor hereby disclaims any warranty that The Software shall be error free, without defects or code which may cause damage to Licensee’s computers or to Licensee, and that Software shall be functional. Licensee shall be solely liable to any damage, defect or loss incurred as a result of operating software and undertake the risks contained in running The Software on License’s Server\[s\] and Website\[s\].
    3.  **Prior Inspection:** Licensee hereby states that he inspected The Software thoroughly and found it satisfactory and adequate to his needs, that it does not interfere with his regular operation and that it does meet the standards and scope of his computer systems and architecture. Licensee found that The Software interacts with his development, website and server environment and that it does not infringe any of End User License Agreement of any software Licensee may use in performing his services. Licensee hereby waives any claims regarding The Software's incompatibility, performance, results and features, and warrants that he inspected the The Software.

8.  **No Refunds:** Licensee warrants that he inspected The Software according to clause 7(c) and that it is adequate to his needs. Accordingly, as The Software is intangible goods, Licensee shall not be, ever, entitled to any refund, rebate, compensation or restitution for any reason whatsoever, even if The Software contains material flaws.
9.  **Indemnification:** Licensee hereby warrants to hold Licensor harmless and indemnify Licensor for any lawsuit brought against it in regards to Licensee’s use of The Software in means that violate, breach or otherwise circumvent this license, Licensor's intellectual property rights or Licensor's title in The Software. Licensor shall promptly notify Licensee in case of such legal action and request Licensee’s consent prior to any settlement in relation to such lawsuit or claim.
10. **Governing Law, Jurisdiction:** Licensee hereby agrees not to initiate class-action lawsuits against Licensor in relation to this license and to compensate Licensor for any legal fees, cost or attorney fees should any claim brought by Licensee against Licensor be denied, in part or in full.
